<?php

namespace App\Http\Controllers;

use App\domain\travelport\QueryCombinableFlightOffersAction;
use App\domain\travelport\QueryOffersPageAction;
use Carbon\Carbon;
use Illuminate\Http\JsonResponse;
use Illuminate\Http\Request;
use Illuminate\Http\Response;
use Illuminate\Support\Facades\Log;

class FlightOfferSearchController extends Controller
{
    public function index(Request $request, QueryCombinableFlightOffersAction $action): JsonResponse
    {
        Log::info("#Search request time: " . Carbon::now());
        try {
            $searchModifiers = [
                "cabinPreference" => $request->input('CabinPreference') ?? null,
                "flightType" => $request->input('flightType') ?? null
            ];

            $combinableOffers = $action->execute(
                $request->input('passengerCriteria'),
                $request->input('searchCriteriaFlight'),
                $searchModifiers
            );

//            $originalResponse['GDS'] = session('GDS');
//            $originalResponse['NDC'] = session('NDC');

            return response()->json([
                'productOffers' => $combinableOffers,
                'total_combined_offers' => session('total_combined_offers'),
                'offers_request_id' => session('offers_request_id'),
//                'original_response' => $originalResponse
            ]);
        } catch (\Exception $exception) {
//            $originalResponse['GDS'] = session('GDS');
//            $originalResponse['NDC'] = session('NDC');
            Log::error("FlightOfferSearchController->index : " . $exception->getMessage());
            return response()->json(
                [
                    'error_message' => $exception->getMessage(),
//                    'original_response' => $originalResponse
                ],
                Response::HTTP_BAD_REQUEST
            );
        }
    }

    public function getOffersPage(Request $request, QueryOffersPageAction $action): JsonResponse
    {
        try {
            $offers = $action->execute(
                $request->input('catalogId'),
                $request->input('page'),
            );

            return response()->json([
                'productOffers' => $offers,
//                'original_response' => $searchResults
            ]);
        } catch (\Exception $exception) {
            Log::error("FlightOfferSearchController->getOffersPage : " . $exception->getMessage());
            return response()->json(['error_message' => $exception->getMessage()], Response::HTTP_BAD_REQUEST);
        }
    }
}
