<?php

namespace App\domain\travelport;

use App\Models\CommitResponse;
use Exception;
use GuzzleHttp\Exception\GuzzleException;
use Illuminate\Support\Collection;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Storage;

class CommitReservation extends Workbench
{
    protected string $reservationId;

    public function execute(string $reservationId)
    {
        $this->reservationId = $reservationId;

        $apiUrl = $this->buildApiUrl();

        try {
            $response = $this->client->post($apiUrl, [
                'headers' => $this->getHeaders()
            ]);

            $reservationResponse = json_decode($response->getBody(), true);

            if (isset($reservationResponse['ReservationResponse']['Reservation']) &&
                !empty($reservationResponse['ReservationResponse']['Reservation'])) {
                $this->saveResponse($reservationResponse);
            }

            return $reservationResponse;
        } catch (Exception $e) {
            Log::error("CommitReservation: Error: " . $e->getMessage());
            return null;
        } catch (GuzzleException $e) {
            Log::error("CommitReservation: Guzzle Reqeust Error: " . $e->getMessage());
            return null;
        }
    }

    protected function buildApiUrl(): string
    {
        return "https://{$this->baseURL}/{$this->apiVersion}/air/book/reservation/reservations/{$this->reservationId}";
    }

    protected function createPayload(): array
    {
        $payload = [
            "ReservationQueryCommitReservation" => [
                "@type" => "ReservationQueryCommitReservation",
                "scheduleChangeAcceptedInd" => true
            ]
        ];
        Storage::put('travelport/api/6-reservationworkbench_commit_request.json', json_encode($payload, JSON_PRETTY_PRINT));
        return $payload;
    }

    protected function saveResponse($response): void
    {
        $receipt = new Collection($response['ReservationResponse']['Reservation']['Receipt']);
        $locatorId = $receipt->where('Confirmation.Locator.source', '1G')->pluck('Confirmation.Locator.value')->first();

        Log::info("Locator ID: ".$locatorId);

        if($locatorId) {
            $commitResponse = new CommitResponse();
            $commitResponse->reservation_id = $this->reservationId;
            $commitResponse->locator_id = $locatorId;
            $commitResponse->response = json_encode($response);
            $commitResponse->save();

            Storage::put('travelport/api/6-reservationworkbench_commit_response.json',json_encode($response, JSON_PRETTY_PRINT));

        }
    }
}
